aboutsummaryrefslogtreecommitdiff
path: root/src/mnemonics/electrum-words.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mnemonics/electrum-words.h')
-rw-r--r--src/mnemonics/electrum-words.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/mnemonics/electrum-words.h b/src/mnemonics/electrum-words.h
index c10e216e8..95c420562 100644
--- a/src/mnemonics/electrum-words.h
+++ b/src/mnemonics/electrum-words.h
@@ -57,10 +57,11 @@ namespace crypto
{
/*!
* \brief Called to initialize it to work with a word list file.
* \param language Language of the word list file.
* \param old_word_list Whether it is to use the old style word list file.
*/
- void init(const std::string &language, bool old_word_list=false);
+ void init(const std::string &language, bool has_checksum=true, bool old_word_list=false);
/*!
* \brief Converts seed words to bytes (secret key).
@@ -57,10 +57,11 @@ namespace crypto
/*!
* \brief Called to initialize it to work with a word list file.
- * \param language Language of the word list file.
- * \param old_word_list Whether it is to use the old style word list file.
+ * \param language Language of the word list file.
+ * \param has_checksum True if the checksum was passed false if not.
+ * \param old_word_list true it is to use the old style word list file false if not.
*/